@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2011 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
@@ -13,6 +13,8 @@
  *    02/22/06 [RCG]
  *            - Handle case where macro redefined
  *            - Don't increment last_index until sure within bounds
+ *            - Increase max MDEF length from 100 to 500 (since max
+ *              length includes name and value)
  *            - Correct error message when MDEF too long
  *
  *    08/13/03 [RCG]
@@ -93,7 +95,9 @@ pop_capa ( POP *p )
 */
     
 # if defined(SCRAM)
-    POP_WRITE_LIT  ( p, "SASL SCRAM-MD5\r\n",             );
+    POP_WRITE_LIT  ( p, "SASL SCRAM-MD5\r\n"             );
+# elif defined(CYRUS_SASL)
+    pop_sasl_mechs ( p );
 # endif
 
 # if !defined(APOP_ONLY) && !defined(SCRAM_ONLY)
@@ -151,7 +155,7 @@ pop_mdef ( POP *p )
     
     
     pop_lower ( p->pop_parm[1] );
-    len = strlen ( p->pop_parm[1] );
+    len = p->pop_parmlen[1];
     if ( len > MAX_MDEF_LENGTH )
         return pop_msg ( p, POP_FAILURE, HERE, "MDEF too long" );
 
