@@ -1,14 +1,16 @@
+/*
+ * Copyright (c) 2011 QUALCOMM Incorporated.  All rights reserved.
+ * The file License.txt specifies the terms for use, modification,
+ * and redistribution.
+ */
+
+
 /*
  * Copyright (c) 1989 Regents of the University of California.
  * All rights reserved.  The Berkeley software License Agreement
  * specifies the terms and conditions for redistribution.
  */
- 
-/*
- * Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
- * The file License.txt specifies the terms for use, modification,
- * and redistribution.
- */
+
 
 /*  LINTLIBRARY */
 
@@ -276,6 +278,10 @@ typedef enum {
 
 typedef struct _pop_tls             pop_tls;            /* defined in pop_tls.h */
 
+#ifdef    CYRUS_SASL
+typedef struct _pop_sasl            pop_sasl;           /* defined in pop_sasl.h */
+#endif /* CYRUS_SASL */
+
 /*
  * We often call pop_write with a literal.  Any half-decent optimizing
  * compiler can calculate the length of a literal string much easier
@@ -352,6 +358,9 @@ typedef enum {                              /* Authentication Method In Use: */
 #ifdef SCRAM
     scram_md5,                              /*     SCRAM-MD5                 */
 #endif
+#ifdef    CYRUS_SASL
+    cyrus_sasl,                             /*     The Cyrus-SASL library */
+#endif /* CYRUS_SASL */
     plain                                   /*     plain text [user/pass or  
                                                                user/rpop]    */
 } auth_type;
@@ -370,6 +379,9 @@ typedef enum {                               /* Authentication Success  Substate
     user,                                    /*  USER under plain or kerberos     */
     pass,                                    /*  PASS under plain or kerberos     */
     rpop,                                    /*  RPOP under plain or kerberos     */
+#ifdef    CYRUS_SASL
+    sasl,                                    /*  SASL success                     */
+#endif /* CYRUS_SASL */
     none                                     /*  not established or don't care    */
 } auth_state;
 
@@ -380,6 +392,7 @@ typedef enum {                               /* Authentication Success  Substate
 typedef enum {                               /* Pool network writes:              */
     ChunkyAlways = 0,                        /* - Always                          */
     ChunkyTLS,                               /* - Only with TLS/SSL               */
+    ChunkySASL,                              /* - Only with SASL                  */
     ChunkyNever                              /* - Never                           */
 } chunky_type;
 
@@ -439,7 +452,8 @@ typedef enum {
  */
 typedef enum {                               /* Config file option is:         */
     CfgBool = 1,                             /* - boolean                      */
-    CfgInt,                                  /* - integer                      */
+    CfgInt,                                  /* - integer (positive)           */
+    CfgIntNeg,                               /* - integer, may be negative     */
     CfgMnem,                                 /* - mnemonic                     */
     CfgStr,                                  /* - string                       */
     CfgBad                                   /* - INVALID VALUE                */
@@ -611,6 +625,7 @@ struct _pop {                                   /*  POP parameter block */
     char            *   pcInStart;
     int                 nInBufUsed;             /*  Bytes in input buffer */
     int                 nInBufStart;            /*  Offset to 1st read byte */
+    int                 nLineLen;               /*  Length of current line */
     FILE            *   output;                 /*  Output TCP/IP communication
                                                     stream */
     char                pcOutBuf[OUT_BUF_SIZE]; /*  Buffer up output so writes
@@ -627,6 +642,7 @@ struct _pop {                                   /*  POP parameter block */
                                                     continuation */
     char            *   inp_buffer;             /*  Input Stream */
     char            *   pop_parm[MAXPARMCOUNT]; /*  Parse POP parameter list */
+    int                 pop_parmlen[MAXPARMCOUNT]; /*length of each parameter*/
     int                 parm_count;             /*  Number of parameters in 
                                                     parsed list */
     char            *   bulldir;                /*  Bulletin directory */
@@ -673,6 +689,12 @@ struct _pop {                                   /*  POP parameter block */
                                                     only) */
 #endif /* SCRAM */
 
+#ifdef    CYRUS_SASL
+    struct _pop_sasl    sasl;                   /* General place to put 
+                                                   SASL items */
+#endif /* CYRUS_SASL */
+    BOOL                sasl_complete;          /* Is SASL auth complete? */
+
     time_t              login_time;             /* Elapsed time to login */
     time_t              init_time;              /* Elapsed time to init drop info */
     time_t              clean_time;             /* Elapsed time to clean up */
@@ -702,6 +724,7 @@ struct _pop {                                   /*  POP parameter block */
     BOOL                bKeep_temp_drop;        /* Keep temp drop file */
     char               *grp_serv_mode;          /* Group for server mode */
     char               *grp_no_serv_mode;       /* Group for no server mode */
+    char               *ext_postauth_cmd;       /* Command to exec on successful auth */
     char               *authfile;               /* Authorization file */
     char               *nonauthfile;            /* Non-authorization file */
     BOOL                bShy;                   /* Hide version from non-auth users */
@@ -718,6 +741,7 @@ struct _pop {                                   /*  POP parameter block */
     log_facility_type   log_facility;           /* Which log facility to use */
     char               *pLog_login;             /* String to use when logging log-ins */
     BOOL                bXtnd_Xmit;             /* Allow XTND XMIT */
+    BOOL                bCons_cache;            /* Be conservative when using cache */
 #if 0 /* can't use this until we have a way to call pam_close_session with privs */
     pam_session_type    call_pam_session;       /* When to call pam_session_* */
 #endif
@@ -822,7 +846,7 @@ int pop_msg (POP *p, pop_result status, const char  *fn, size_t ln, const char *
 int pop_logv(POP *p, log_level  loglev, const char  *fn, size_t ln, const char *format, va_list ap ) ATTRIB_FMT(5,0); /* parameters for format string */
 
 int  cache_write   (POP *p, int spool_fd, MsgInfoList *mp);
-int  cache_read    (POP *p, int spool_fd, MsgInfoList **mp);
+int  cache_read    (POP *p, FILE* spool_fd, MsgInfoList **mp);
 void cache_unlink  (POP *p);
 
 pop_tls *pop_tls_init(POP *pPOP);
@@ -832,6 +856,12 @@ int      pop_tls_flush(pop_tls *);
 int      pop_tls_read(pop_tls *, char *, int);
 void     pop_tls_shutdown(POP *pPOP);
 
+void     pop_sasl_mechs(POP *p);
+int      pop_sasl_write(POP *, char *, int);
+int      pop_sasl_read(POP *, char *, int);
+int      pop_sasl_flush(POP *);
+void     pop_sasl_done(POP *p);
+
 int  mkstemp       (char *path);
 void pop_lower     (char *buf);
 
