@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2011 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  */
@@ -39,7 +39,7 @@ POP     *   p;
     char                    buffer[MAXLINELEN];     /*  Read buffer */
     MsgInfoList         *   mp;         /*  Pointer to message info list */
     int min,max;
-    int len = strlen(p->pop_parm[2]);
+    int len = p->pop_parmlen[2];
 
     /*  Convert the first parameter into an integer */
     if (p->parm_count==3)
